#!/bin/bash
############################################################################
# 0DaysDateFix v1.2 by Turranius                                           #
####                                                                    ####
# This little script will change the date on any dated dirs, be it 0days   #
# or Mp3 folders. The only requirement is that the dirs in in the format   #
# "MonthDay", like 0628.                                                   #
####                                                                    ####
# Installation:                                                            #
# Put this script in /glftpd/bin, or wherever you like really.             #
# Make it executable.                                                      #
# Edit the settings below:                                                 #
# DATEDDIRS can be any number of folders containing dated dirs, space      #
# separated.                                                               #
#                                                                          #
# To rename folders from mmdd to mmddyy, add a ~ after its path.           #
# This is for archives more then a year old. It will check the year of the #
# folder so make sure any dirs from, say 01, really dosnt have a date of   #
# 02. This might not work on all distros. Search for year= and change it   #
# if it does not. I cant say how its supposed to be on your distro though. #
# Only tested on RedHat and Mandrake.                                      #
# It will make a check to see that the dir is really 4 chars long first.   #
#                                                                          #
# Any folders contained in these dated dirs can be excluded in EXCLUDE.    #
# Separate the excludes with a |                                           #
# Crontab it or just run it manually as often or seldom as you like.       #
# To run it 15 minutes past midnight, each day, do:                        #
# 15 0 * * * /glftpd/bin/0daysdatefix.sh                                   #
#                                                                          #
# If you wish to see whats happening when its running, start it with the   #
# variable 'display' (0daysdatefix.sh display).                            #
####                                                                    ####
# Changelog:                                                               #
# 1.2   : Added option to rename dated folders from mmdd to mmddyy.        #
#         Only enable this in archive dirs.                                #
# 1.1.1 : Fixed it where it would not run the first 9 days of the month.   #
# 1.1 : Handles an infinite amount of dated dirs.                          #
#       Excludes are working.                                              #
#       Better (?) documented, hehe.                                       #
# 1.0 : Initial release. Only handles one dir.                             #
############################################################################
# Contact Turranius on efnet (turranius/turran/turr|away/turr|work).       #
############################################################################

DATEDDIRS="
/glftpd/site/0day
/glftpd/site/Archive/0day1~
/glftpd/site/Archive/0day2~
/glftpd/site/Mp3
"   
# Space separeted

EXCLUDE='lost\+found|journ|GROUPS|!Today|!Yesterday' # | separated


############################################################
## No changes below needed                                 #
############################################################

today="$(date +%m%d)"

for dir in $DATEDDIRS; do
  rename="$( echo $dir | grep "~" )"
  if [ "$rename" != "" ]; then
    dir="$( echo $dir | awk -F"~" '{print $1}' )"
    renameit="yes"
  else
    renameit="no"
  fi

  cd $dir

  for i in `ls -f -A | egrep -v $EXCLUDE`; do
    if [ "$i" != "$today" ]; then 
      if [ "$1" = "display" ]; then
        echo $dir/$i
      fi
      if [ "$renameit" = "yes" ]; then
        lenght="$( echo $i | wc -L | tr -d ' ' )"
        if [ "$lenght" = "4" ]; then
          year="$( ls --full-time $dir | grep -w $i | awk '{print $10}' | cut -b3-4 )"
          mv -f $i $i$year
          folder="$i$year"
          touch $folder -t $year$i"0000"
        fi
      else
        touch $i -t $i"0000"
      fi
    else
      if [ "$1" = "display" ]; then
        echo "Not touching todays dir: $dir/$i"
      fi
    fi
  done
done

exit 0
